@@ -2,7 +2,7 @@ import os
 import time
 from typing import Optional
 
-from rubberduck_chat.chat_gpt.chat import GptChat, GptChatSession
+from rubberduck_chat.chat_gpt.chat import GptChat, GptChatSession, GptChatSessionConfigs
 from rubberduck_chat.chat_gpt.credentials import setup_gpt_credentials
 from rubberduck_chat.chat_gpt.session_store import get_gpt_dir_path, get_gpt_session_dir_path, \
   create_get_gpt_session_dir, remove_old_sessions, get_active_session, get_preview_for_session, set_active_session_id
@@ -16,22 +16,29 @@ def setup_gpt(openai_api_key: Optional[str]) -> GptChat:
   os.makedirs(get_gpt_session_dir_path(), exist_ok=True)
 
   setup_gpt_credentials(openai_api_key)
+  chat_session_configs = get_gpt_chat_configs()
   create_get_gpt_session_dir()
   remove_old_sessions(max_saved_session_count)
-  previous_session = restore_previous_session()
+  previous_session = restore_previous_session(chat_session_configs)
 
   if previous_session:
-    return GptChat(previous_session)
+    return GptChat(previous_session, chat_session_configs)
   else:
-    return GptChat(get_new_session())
+    return GptChat(get_new_session(chat_session_configs), chat_session_configs)
 
 
-def restore_previous_session() -> Optional[GptChatSession]:
+def get_gpt_chat_configs() -> GptChatSessionConfigs:
+  return GptChatSessionConfigs(config_collection.max_messages_per_request.get_int_value(),
+                               config_collection.snippet_header_background_color.get_value(),
+                               config_collection.snippet_theme.get_value())
+
+
+def restore_previous_session(configs: GptChatSessionConfigs) -> Optional[GptChatSession]:
   always_continue_last_session = config_collection.always_continue_last_session.get_bool_value()
   active_session = get_active_session()
 
   if always_continue_last_session and active_session:
-    return GptChatSession.from_session_id(active_session.session_id)
+    return GptChatSession.from_session_id(active_session.session_id, configs)
 
   if active_session:
     old_session_cutoff_time_in_seconds = config_collection.inactive_session_cutoff_time_in_seconds.get_int_value()
@@ -39,13 +46,13 @@ def restore_previous_session() -> Optional[GptChatSession]:
       time.time()) - old_session_cutoff_time_in_seconds > active_session.last_active_time
 
     if not is_active_session_expired:
-      return GptChatSession.from_session_id(active_session.session_id)
+      return GptChatSession.from_session_id(active_session.session_id, configs)
 
   return None
 
 
-def get_new_session() -> Optional[GptChatSession]:
-  session = GptChatSession.create_new()
+def get_new_session(session_configs: GptChatSessionConfigs) -> Optional[GptChatSession]:
+  session = GptChatSession.create_new(session_configs)
   set_active_session_id(session.session_id)
   return session
 
